@@ -18,7 +18,7 @@ import model_tree
 class HierarchicalModel(models.Model):
     "A generic hierarchical database model."
 
-    left_visit = models.IntegerField(primary_key=True)
+    left_visit = models.IntegerField(db_index=True)
     right_visit = models.IntegerField(db_index=True)
 
     class Meta:
@@ -48,12 +48,12 @@ class HierarchicalModel(models.Model):
         cursor = connection.cursor()
         cursor.execute("""
                 UPDATE %s SET right_visit = right_visit + 2
-                WHERE right_visit >= %s
-            """, (cls._meta.db_table, parent_right_visit))
+                WHERE right_visit >= %%s
+            """ % cls._meta.db_table, (parent_right_visit,))
         cursor.execute("""
                 UPDATE %s SET left_visit = left_visit + 2
-                WHERE left_visit > %s
-            """, (cls._meta.db_table, parent_right_visit))
+                WHERE left_visit > %%s
+            """ % cls._meta.db_table, (parent_right_visit,))
 
         kwargs['left_visit'] = parent_right_visit
         kwargs['right_visit'] = parent_right_visit + 1
