@@ -11,6 +11,8 @@
 
 from random import shuffle
 
+import consoleLog
+
 class TreeNode(object):
     """
     A node in a hierarchical labelled tree. Each node contains links both
@@ -273,9 +275,15 @@ class TreeNode(object):
         if method is None:
             method = lambda n: n.label
 
-        print method(self)
-        self._layout_children(self, '', method)
-        return
+        log = consoleLog.default
+
+        if self.children:
+            log.start(method(self), nSteps=len(self.children))
+            for child in self.children.itervalues():
+                child.layout(method)
+            log.finish()
+        else:
+            log.log(method(self))
 
     def store(self, ModelClass, label_field='label'):
         """
@@ -300,21 +308,6 @@ class TreeNode(object):
     # PRIVATE
     #------------------------------------------------------------------------#
 
-    def _layout_children(self, node, prefix, method):
-        children = node.children.values()
-        if not children:
-            return
-
-        for child in children[:-1]:
-            print '%s├─ %s' % (prefix, method(child))
-            self._layout_children(child, prefix + '│  ', method)
-        
-        child = children[-1]
-        print '%s└─ %s' % (prefix, method(child))
-        self._layout_children(child, prefix + '   ', method)
-
-        return
-
 #----------------------------------------------------------------------------#
 
 class TreeDist(object):
